@@ -2,7 +2,7 @@
 sentry.coreapi
 ~~~~~~~~~~~~~~
 
-:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 # TODO: We should make the API a class, and UDP/HTTP just inherit from it
@@ -13,6 +13,7 @@ from datetime import datetime
 import base64
 import logging
 import time
+import uuid
 import zlib
 
 from django.utils.encoding import smart_str
@@ -193,6 +194,9 @@ def process_data_timestamp(data):
 def validate_data(project, data):
     ensure_valid_project_id(project, data)
 
+    if 'event_id' not in data:
+        data['event_id'] = uuid.uuid4().hex
+
     if 'timestamp' in data:
         process_data_timestamp(data)
 
