@@ -1,3 +1,10 @@
+"""
+sentry.web.frontend.projects
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2012 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
@@ -5,6 +12,7 @@ from django.views.decorators.csrf import csrf_protect
 
 from sentry.conf import settings
 from sentry.models import ProjectMember, MEMBER_USER, MEMBER_OWNER
+from sentry.permissions import can_create_projects
 from sentry.plugins import plugins
 from sentry.web.decorators import login_required, has_access
 from sentry.web.forms import EditProjectForm, NewProjectForm, \
@@ -17,11 +25,10 @@ from sentry.web.helpers import render_to_response, get_project_list, \
 @login_required
 def project_list(request):
     project_list = get_project_list(request.user, hidden=True)
-    memberships = dict(
-        (p.project_id, p)
-        for p in ProjectMember.objects.filter(user=request.user, project__in=project_list)
-    )
-    for project_id, member in memberships.iteritems():
+    memberships = list(ProjectMember.objects.filter(user=request.user, project__in=project_list))
+
+    for member in memberships:
+        project_id = member.project_id
         project_list[project_id].member_dsn = member.get_dsn(request.get_host(), secure=request.is_secure())
         project_list[project_id].member_type = member.get_type_display()
 
@@ -33,7 +40,7 @@ def project_list(request):
 @login_required
 @csrf_protect
 def new_project(request):
-    if not (settings.ALLOW_PROJECT_CREATION or request.user.has_perm('sentry.can_add_project')):
+    if not can_create_projects(request.user):
         return HttpResponseRedirect(reverse('sentry'))
 
     if request.user.has_perm('sentry.can_add_project'):
@@ -68,6 +75,10 @@ def remove_project(request, project):
     if str(project.id) == str(settings.PROJECT):
         return HttpResponseRedirect(reverse('sentry-project-list'))
 
+    result = plugins.first('has_perm', request.user, 'remove_project', project)
+    if result is False and not request.user.has_perm('sentry.can_remove_project'):
+        return HttpResponseRedirect(reverse('sentry'))
+
     project_list = filter(lambda x: x != project, get_project_list(request.user).itervalues())
 
     form = RemoveProjectForm(project_list, request.POST or None)
@@ -99,6 +110,10 @@ def remove_project(request, project):
 @has_access(MEMBER_OWNER)
 @csrf_protect
 def manage_project(request, project):
+    result = plugins.first('has_perm', request.user, 'edit_project', project)
+    if result is False and not request.user.has_perm('sentry.can_change_project'):
+        return HttpResponseRedirect(reverse('sentry'))
+
     form = EditProjectForm(request.POST or None, instance=project)
 
     if form.is_valid():
@@ -122,6 +137,10 @@ def manage_project(request, project):
 @csrf_protect
 @has_access(MEMBER_OWNER)
 def new_project_member(request, project):
+    result = plugins.first('has_perm', request.user, 'add_project_member', project)
+    if result is False and not request.user.has_perm('sentry.can_add_projectmember'):
+        return HttpResponseRedirect(reverse('sentry'))
+
     form = NewProjectMemberForm(project, request.POST or None, initial={
         'type': MEMBER_USER,
     })
@@ -146,6 +165,10 @@ def new_project_member(request, project):
 def edit_project_member(request, project, member_id):
     member = project.member_set.get(pk=member_id)
 
+    result = plugins.first('has_perm', request.user, 'edit_project_member', member)
+    if result is False and not request.user.has_perm('sentry.can_change_projectmember'):
+        return HttpResponseRedirect(reverse('sentry'))
+
     form = EditProjectMemberForm(project, request.POST or None, instance=member)
     if form.is_valid():
         member = form.save(commit=True)
@@ -170,6 +193,10 @@ def remove_project_member(request, project, member_id):
     if member.user == project.owner:
         return HttpResponseRedirect(reverse('sentry-project-list'))
 
+    result = plugins.first('has_perm', request.user, 'remove_project_member', member)
+    if result is False and not request.user.has_perm('sentry.can_remove_projectmember'):
+        return HttpResponseRedirect(reverse('sentry'))
+
     if request.POST:
         member.delete()
 
@@ -193,6 +220,10 @@ def configure_project_plugin(request, project, slug):
     except KeyError:
         return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.pk]))
 
+    result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
+    if result is False and not request.user.is_superuser:
+        return HttpResponseRedirect(reverse('sentry'))
+
     form = plugin.project_conf_form
     if form is None:
         return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.pk]))
